-- =============================================
-- SaveToDB Framework for Azure SQL Data Warehouse
-- Version 8.15, November 7, 2018
--
-- This script upgrades SaveToDB Framework 8.11 to SaveToDB Framework 8.15
--
-- Copyright 2011-2018 Gartle Technology Corporation
-- =============================================

UPDATE xls.handlers  SET HANDLER_CODE = 'TABLE, VIEW, PROCEDURE, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET' WHERE TABLE_SCHEMA = 'xls' AND TABLE_NAME = 'handlers' AND COLUMN_NAME = 'HANDLER_TYPE' AND EVENT_NAME = 'ValidationList';
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     8.15, 2018-11-07
-- Description: SaveToDB Query List
-- =============================================

ALTER VIEW [xls].[queries]
AS

SELECT
    s.name AS TABLE_SCHEMA
    , o.name AS TABLE_NAME
    , CASE o.[type] WHEN 'U' THEN 'BASE TABLE' WHEN 'V' THEN 'VIEW' WHEN 'P' THEN 'PROCEDURE' WHEN 'IF' THEN 'FUNCTION' ELSE o.type_desc COLLATE Latin1_General_CI_AS END AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    sys.objects o
    INNER JOIN sys.schemas s ON s.[schema_id] = o.[schema_id]
WHERE
    o.[type] IN ('U', 'V', 'P', 'IF')
    AND NOT s.name IN ('sys', 'xls', 'etl01', 'dbo01', 'xls01', 'savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'SAVETODB_DEV', 'SAVETODB_XLS', 'SAVETODB_ETL')
    AND NOT (s.name = 'dbo' AND (
           o.name LIKE 'sp_%'
        OR o.name LIKE 'fn_%'
        OR o.name LIKE 'sys%'
        ))
    AND NOT o.name LIKE 'xl_%'
    AND NOT (o.[type] = 'V' AND (
           o.name LIKE 'viewQueryList%'
        OR o.name LIKE 'viewParameterValues%'
        OR o.name LIKE 'viewValidationList%'
        OR o.name LIKE 'view_query_list%'
        OR o.name LIKE 'view_xl_%'
        ))
    AND NOT (o.[type] = 'P' AND (
           o.name LIKE '%_insert'
        OR o.name LIKE '%_update'
        OR o.name LIKE '%_delete'
        OR o.name LIKE '%_merge'
        OR o.name LIKE '%_change'
        OR o.name LIKE 'uspExcelEvent%'
        OR o.name LIKE 'uspParameterValues%'
        OR o.name LIKE 'uspValidationList%'
        OR o.name LIKE 'uspAdd%'
        OR o.name LIKE 'uspSet%'
        OR o.name LIKE 'uspInsert%'
        OR o.name LIKE 'uspUpdate%'
        OR o.name LIKE 'uspDelete%'
        OR o.name LIKE 'Add%'
        OR o.name LIKE 'Set%'
        OR o.name LIKE 'Insert%'
        OR o.name LIKE 'Update%'
        OR o.name LIKE 'Delete%'
        OR o.name LIKE 'usp_xl_%'
        ))
    AND NOT (o.[type] = 'IF' AND (
           o.name LIKE 'Has%'
        OR o.name LIKE 'ufnExcelEvent%'
        OR o.name LIKE 'ufnParameterValues%'
        OR o.name LIKE 'ufn_xl_%'
        ))
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE COLLATE Latin1_General_CI_AS
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    xls.[objects] o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_SCHEMA IS NOT NULL
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL
    AND NOT o.TABLE_NAME LIKE 'xl_%'


GO
